From e5f573b9ca243aa70307fdfb75c5120d1ad65dba Mon Sep 17 00:00:00 2001
From: Ted Bowman <41201-tedbow@users.noreply.drupalcode.org>
Date: Tue, 17 Oct 2023 14:27:28 +0000
Subject: [PATCH] Issue #3391715: Change core merge request converter to either
 produce the Package Manager only MR or with AutoUpdates

---
 auto-update                                   |   0
 automatic_updates.module                      |   5 +-
 automatic_updates.services.yml                |   4 +-
 config/schema/automatic_updates.schema.yml    |   2 +-
 dictionary.txt                                |   1 +
 package_manager/src/Error.php                 |  34 ++++
 package_manager/src/FailureMarker.php         |   2 +-
 scripts/src/Converter.php                     | 156 ++++++++++++++----
 src/CommandExecutor.php                       |   7 +-
 src/ConsoleUpdateStage.php                    |   2 +-
 src/CronUpdateRunner.php                      |  10 +-
 src/StatusCheckMailer.php                     |   2 +-
 tests/src/Build/CoreUpdateTest.php            |  14 +-
 .../AutomaticUpdatesFunctionalTestBase.php    |   1 +
 .../StatusCheckFailureEmailTest.php           |  30 ++--
 tests/src/Kernel/ConsoleUpdateStageTest.php   |  22 +--
 .../Traits/EmailNotificationsTestTrait.php    |   4 +-
 17 files changed, 216 insertions(+), 80 deletions(-)
 mode change 100755 => 100644 auto-update
 create mode 100644 package_manager/src/Error.php

diff --git a/auto-update b/auto-update
old mode 100755
new mode 100644
diff --git a/automatic_updates.module b/automatic_updates.module
index 530a4daeba..0955bc689e 100644
--- a/automatic_updates.module
+++ b/automatic_updates.module
@@ -17,6 +17,7 @@ use Drupal\Core\Routing\RouteMatchInterface;
 use Drupal\automatic_updates\Validation\AdminStatusCheckMessages;
 use Drupal\Core\Url;
 use Drupal\package_manager\ComposerInspector;
+use Drupal\package_manager\Error;
 use Drupal\system\Controller\DbUpdateController;
 
 /**
@@ -111,7 +112,7 @@ function automatic_updates_mail(string $key, array &$message, array $params): vo
   // If this email was related to an unattended update, explicitly state that
   // this isn't supported yet.
   if (str_starts_with($key, 'cron_')) {
-    $message['body'][] = t('This e-mail was sent by the Automatic Updates module. Unattended updates are not yet fully supported.', [], $options);
+    $message['body'][] = t('This email was sent by the Automatic Updates module. Unattended updates are not yet fully supported.', [], $options);
     $message['body'][] = t('If you are using this feature in production, it is strongly recommended for you to visit your site and ensure that everything still looks good.', [], $options);
   }
 }
@@ -276,7 +277,7 @@ function automatic_updates_preprocess_update_project_status(array &$variables) {
   catch (RuntimeException $exception) {
     // If for some reason we are not able to get the update recommendations
     // do not alter the report.
-    watchdog_exception('automatic_updates', $exception);
+    Error::logException(\Drupal::logger('automatic_updates'), $exception);
     return;
   }
   $variables['#attached']['library'][] = 'automatic_updates/update_status';
diff --git a/automatic_updates.services.yml b/automatic_updates.services.yml
index 8df2e2f62f..d6344fa5bf 100644
--- a/automatic_updates.services.yml
+++ b/automatic_updates.services.yml
@@ -53,4 +53,6 @@ services:
   Drupal\automatic_updates\MaintenanceModeAwareCommitter:
     tags:
       - { name: event_subscriber }
-  Drupal\automatic_updates\CommandExecutor: {}
+  Drupal\automatic_updates\CommandExecutor:
+    arguments:
+      $appRoot: '%app.root%'
diff --git a/config/schema/automatic_updates.schema.yml b/config/schema/automatic_updates.schema.yml
index 9542782743..ff20d21b09 100644
--- a/config/schema/automatic_updates.schema.yml
+++ b/config/schema/automatic_updates.schema.yml
@@ -26,4 +26,4 @@ automatic_updates.settings:
       label: 'Allow minor level Drupal core updates'
     status_check_mail:
       type: string
-      label: 'Whether to send status check failure e-mail notifications during cron'
+      label: 'Whether to send status check failure email notifications during cron'
diff --git a/dictionary.txt b/dictionary.txt
index 9071f6cab1..2cfca2bc88 100644
--- a/dictionary.txt
+++ b/dictionary.txt
@@ -12,3 +12,4 @@ unshallow
 hhvm
 proc_open
 bootable
+Syncer
diff --git a/package_manager/src/Error.php b/package_manager/src/Error.php
new file mode 100644
index 0000000000..9471f2c7e6
--- /dev/null
+++ b/package_manager/src/Error.php
@@ -0,0 +1,34 @@
+<?php
+
+namespace Drupal\package_manager;
+
+use Psr\Log\LoggerInterface;
+use Psr\Log\LogLevel;
+use Drupal\Core\Utility\Error as CoreError;
+
+/**
+ * Temporary class until 10.0.x is no longer supported.
+ *
+ * // @todo Remove this class in https://drupal.org/i/3377458.
+ */
+class Error {
+
+  /**
+   * Log a formatted exception message to the provided logger.
+   *
+   * @param \Psr\Log\LoggerInterface $logger
+   *   The logger.
+   * @param \Throwable $exception
+   *   The exception.
+   * @param string $message
+   *   (optional) The message.
+   * @param array $additional_variables
+   *   (optional) Any additional variables.
+   * @param string $level
+   *   The PSR log level. Must be valid constant in \Psr\Log\LogLevel.
+   */
+  public static function logException(LoggerInterface $logger, \Throwable $exception, string $message = CoreError::DEFAULT_ERROR_MESSAGE, array $additional_variables = [], string $level = LogLevel::ERROR): void {
+    $logger->log($level, $message, CoreError::decodeException($exception) + $additional_variables);
+  }
+
+}
diff --git a/package_manager/src/FailureMarker.php b/package_manager/src/FailureMarker.php
index 6f2a60b90f..f5f5f00800 100644
--- a/package_manager/src/FailureMarker.php
+++ b/package_manager/src/FailureMarker.php
@@ -105,7 +105,7 @@ final class FailureMarker implements EventSubscriberInterface {
    * @param bool $include_backtrace
    *   Whether to include the backtrace in the message. Defaults to TRUE. May be
    *   set to FALSE in a context where it does not make sense to include, such
-   *   as e-mails.
+   *   as emails.
    *
    * @return string|null
    *   The message from the file if it exists, otherwise NULL.
diff --git a/scripts/src/Converter.php b/scripts/src/Converter.php
index cd6a2fd752..6edb09b80d 100644
--- a/scripts/src/Converter.php
+++ b/scripts/src/Converter.php
@@ -10,6 +10,8 @@ use Symfony\Component\Filesystem\Filesystem;
 /**
  * Converts the contrib module to core merge request.
  *
+ * Cspell:disable.
+ *
  * File usage:
  *
  * @code
@@ -41,15 +43,20 @@ class Converter {
   public static function doConvert(Event $event): void {
     $args = $event->getArguments();
     $count_arg = count($args);
-    if (!($count_arg === 2 || $count_arg === 3)) {
-      throw new \Exception("This scripts 2 required arguments: a directory that is a core clone and the branch.\nIt has 1 optional arguments: the branch of this module to use which defaults to 3.0.x");
+    if (!($count_arg === 3 || $count_arg === 4)) {
+      throw new \Exception("This scripts 3 required arguments: a directory that is a core clone and the branch and to convert either package_manager or automatic_updates.\nIt has 1 optional arguments: the branch of this module to use which defaults to 3.0.x");
     }
     $core_dir = $args[0];
     $core_branch = $args[1];
     if (!is_dir($core_dir)) {
       throw new \Exception("$core_dir is not a directory.");
     }
-    $contrib_branch = $count_arg === 2 ? '3.0.x' : $args[2];
+    $package_manager_only = match($args[2]) {
+      'package_manager' => TRUE,
+      'automatic_updates' => FALSE,
+      default => throw new \UnexpectedValueException("The 3nd argument must be package_manager or automatic_updates"),
+    };
+    $contrib_branch = $count_arg === 3 ? '3.0.x' : $args[3];
     $old_machine_name = 'automatic_updates';
     $new_machine_name = 'auto_updates';
 
@@ -68,22 +75,30 @@ class Converter {
     $fs->mirror(self::getContribDir(), $core_module_path);
     self::info('Mirrored into core module');
 
-    $new_script_path = "$core_dir/core/scripts/PackageManagerFixtureCreator.php";
-    $fs->remove($new_script_path);
-    $fs->rename($core_module_path . '/scripts/PackageManagerFixtureCreator.php', $new_script_path);
-    $script_replacements = [
-      "__DIR__ . '/../../../autoload.php'" => "__DIR__ . '/../../autoload.php'",
-      "__DIR__ . '/../package_manager/tests/fixtures/fake_site'" => "__DIR__ . '/../modules/package_manager/tests/fixtures/fake_site'",
-      "CORE_ROOT_PATH = __DIR__ . '/../../../'" => "CORE_ROOT_PATH = __DIR__ . '/../..'",
-      "new Process(['composer', 'phpcbf'], self::FIXTURE_PATH);" => "new Process(['composer', 'phpcbf', self::FIXTURE_PATH], self::CORE_ROOT_PATH);",
+    $replacements = [
+      $old_machine_name => $new_machine_name,
+      'AutomaticUpdates' => 'AutoUpdates',
+      'use Drupal\package_manager\Error;' => 'use Drupal\Core\Utility\Error;',
+      "__DIR__ . '/../../../package_manager/tests" => "__DIR__ . '/../../../../Xpackage_manager/tests",
+      "__DIR__ . '/../../../../package_manager/tests" => "__DIR__ . '/../../../../../Xpackage_manager/tests",
+      "__DIR__ . '/../../../../../package_manager/tests" => "__DIR__ . '/../../../../../../Xpackage_manager/tests",
+      '/Xpackage_manager' => '/package_manager',
     ];
-    foreach ($script_replacements as $search => $replace) {
-      static::replaceContents([new \SplFileInfo($new_script_path)], $search, $replace);
+    foreach ($replacements as $search => $replace) {
+      static::renameFiles(static::getDirContents($core_module_path), $search, $replace);
+      static::replaceContents(static::getDirContents($core_module_path, TRUE), $search, $replace);
     }
+    self::info('Replacements done.');
+
+    static::removeLines($core_dir);
+    self::info('Remove unneeded lines');
+
+    self::moveScripts($core_dir, $core_module_path, $package_manager_only);
+    self::info('Moved scripts');
 
     // Remove unneeded.
     $removals = [
-      'automatic_updates_extensions',
+      'auto_updates_extensions',
       'drupalci.yml',
       'README.md',
       '.cspell.json',
@@ -107,37 +122,34 @@ class Converter {
     // Replace in file names and contents.
     static::replaceContents(
       [
-        new \SplFileInfo("$core_module_path/automatic_updates.info.yml"),
+        new \SplFileInfo("$core_module_path/auto_updates.info.yml"),
         new \SplFileInfo("$core_module_path/package_manager/package_manager.info.yml"),
       ],
       "core_version_requirement: ^10",
       "package: Core\nversion: VERSION\nlifecycle: experimental",
     );
-    $replacements = [
-      $old_machine_name => $new_machine_name,
-      'AutomaticUpdates' => 'AutoUpdates',
-    ];
-    foreach ($replacements as $search => $replace) {
-      static::renameFiles(static::getDirContents($core_module_path), $search, $replace);
-      static::replaceContents(static::getDirContents($core_module_path, TRUE), $search, $replace);
-    }
-    self::info('Replacements done.');
 
-    static::removeLines($core_dir);
-    self::info('Remove unneeded lines');
     $fs->rename("$core_module_path/package_manager", $package_manager_core_path);
     self::info('Move package manager');
 
-    // ⚠️ For now, we're only trying to get package_manager committed, not automatic_updates!
-    $fs->remove($core_module_path);
+    static::copyGenericTest($package_manager_core_path, $core_dir);
 
-    static::addWordsToDictionary($core_dir, self::getContribDir() . "/dictionary.txt");
-    self::info("Added to dictionary");
-    $fs->chmod($new_script_path, 0644);
-    chdir($core_dir);
     // Run phpcbf because removing code from merge request may result in unused
     // use statements or multiple empty lines.
     system("composer phpcbf $package_manager_core_path");
+    if ($package_manager_only) {
+      $fs->remove($core_module_path);
+    }
+    else {
+      static::copyGenericTest($core_module_path, $core_dir);
+      system("composer phpcbf $core_module_path");
+    }
+
+    static::addWordsToDictionary($core_dir, self::getContribDir() . "/dictionary.txt");
+    self::info("Added to dictionary");
+
+    chdir($core_dir);
+
     if (self::RUN_CHECKS) {
       static::runCoreChecks($core_dir);
       self::info('Ran core checks');
@@ -263,6 +275,13 @@ class Converter {
     $files = [];
     /** @var \SplFileInfo $file */
     foreach ($rii as $file) {
+      // Exclude the .git directories always.
+      if ($file->getFilename() === '.git') {
+        continue;
+      }
+      if (str_contains($file->getRealPath(), '/.git/') || str_ends_with($file->getRealPath(), '/.git')) {
+        continue;
+      }
       if ($excludeDirs && $file->isDir()) {
         continue;
       }
@@ -442,11 +461,80 @@ class Converter {
         throw new \Exception("Didn't find ending token");
       }
       // Remove extra blank.
-      if ($newLines[count($newLines) - 1] === '' && $newLines[count($newLines) - 2] === '') {
-        array_pop($newLines);
+      $newLineCnt = count($newLines);
+      if ($newLineCnt > 1) {
+        if ($newLines[count($newLines) - 1] === '' && $newLines[count($newLines) - 2] === '') {
+          array_pop($newLines);
+        }
+      }
+      else {
+        print "\n**Small new line cnt: in $file**\n";
       }
       file_put_contents($filePath, implode("\n", $newLines));
     }
   }
 
+  /**
+   * Move scripts.
+   *
+   * @param string $core_dir
+   *   The core directory.
+   * @param string $core_module_path
+   *   The core module path.
+   * @param bool $package_manager_only
+   *   Whether we are only converting package manager.
+   */
+  protected static function moveScripts(string $core_dir, string $core_module_path, bool $package_manager_only): void {
+    $fs = new Filesystem();
+    $new_fixture_creator_path = "$core_dir/core/scripts/PackageManagerFixtureCreator.php";
+
+    $move_files = [
+      $core_module_path . '/scripts/PackageManagerFixtureCreator.php' => $new_fixture_creator_path,
+    ];
+    if (!$package_manager_only) {
+      $new_auto_update_path = "$core_dir/core/scripts/auto-update";
+      $move_files[$core_module_path . '/auto-update'] = $new_auto_update_path;
+    }
+    foreach ($move_files as $old_file => $new_file) {
+      $fs->remove($new_file);
+      $fs->rename($old_file, $new_file);
+      $fs->chmod($new_file, 0644);
+    }
+    $script_replacements = [
+      "__DIR__ . '/../../../autoload.php'" => "__DIR__ . '/../../autoload.php'",
+      "__DIR__ . '/../package_manager/tests/fixtures/fake_site'" => "__DIR__ . '/../modules/package_manager/tests/fixtures/fake_site'",
+      "CORE_ROOT_PATH = __DIR__ . '/../../../'" => "CORE_ROOT_PATH = __DIR__ . '/../..'",
+      "new Process(['composer', 'phpcbf'], self::FIXTURE_PATH);" => "new Process(['composer', 'phpcbf', self::FIXTURE_PATH], self::CORE_ROOT_PATH);",
+    ];
+    foreach ($script_replacements as $search => $replace) {
+      static::replaceContents([new \SplFileInfo($new_fixture_creator_path)], $search, $replace);
+    }
+    if (!$package_manager_only) {
+      static::replaceContents(
+        [new \SplFileInfo($new_auto_update_path)],
+        "__DIR__ . '/src/Commands'",
+        "__DIR__ . '/../modules/auto_updates/src/Commands'"
+      );
+    }
+
+  }
+
+  /**
+   * Copies a generic test into the new module.
+   *
+   * @param string $new_module_path
+   *   The module path.
+   * @param string $core_dir
+   *   The core dir.
+   */
+  private static function copyGenericTest(string $new_module_path, string $core_dir): void {
+    $parts = explode('/', $new_module_path);
+    $module_name = array_pop($parts);
+    $original_test = "$core_dir/core/modules/action/tests/src/Functional/GenericTest.php";
+    $new_test = "$new_module_path/tests/src/Functional/GenericTest.php";
+    $fs = new Filesystem();
+    $fs->copy($original_test, $new_test);
+    static::replaceContents([new \SplFileInfo($new_test)], 'action', $module_name);
+  }
+
 }
diff --git a/src/CommandExecutor.php b/src/CommandExecutor.php
index 5b315a9b75..d6c7d39fe2 100644
--- a/src/CommandExecutor.php
+++ b/src/CommandExecutor.php
@@ -28,11 +28,14 @@ final class CommandExecutor {
    *   The file system service.
    * @param \Drupal\Component\Datetime\TimeInterface $time
    *   The time service.
+   * @param string $appRoot
+   *   The application root.
    */
   public function __construct(
     private readonly PathLocator $pathLocator,
     private readonly FileSystemInterface $fileSystem,
     private readonly TimeInterface $time,
+    private readonly string $appRoot
   ) {}
 
   /**
@@ -47,8 +50,10 @@ final class CommandExecutor {
    *   way, with the `--host` and `--site-path` options always set.
    */
   public function create(string $arguments = NULL): Process {
+    $script = $this->appRoot . '/core/scripts/auto-update';
+    // BEGIN: DELETE FROM CORE MERGE REQUEST
     $script = __DIR__ . '/../auto-update';
-
+    // END: DELETE FROM CORE MERGE REQUEST
     $command_line = implode(' ', [
       // Always run the command script directly through the PHP interpreter.
       (new PhpExecutableFinder())->find(),
diff --git a/src/ConsoleUpdateStage.php b/src/ConsoleUpdateStage.php
index 9131c62422..84861a53ae 100644
--- a/src/ConsoleUpdateStage.php
+++ b/src/ConsoleUpdateStage.php
@@ -220,7 +220,7 @@ class ConsoleUpdateStage extends UpdateStage {
         'target_version' => $target_version,
         'error_message' => $e->getMessage(),
       ];
-      // Omit the backtrace in e-mails. That will be visible on the site, and is
+      // Omit the backtrace in emails. That will be visible on the site, and is
       // also stored in the failure marker.
       if ($e instanceof StageFailureMarkerException || $e instanceof ApplyFailedException) {
         $mail_params['error_message'] = $this->failureMarker->getMessage(FALSE);
diff --git a/src/CronUpdateRunner.php b/src/CronUpdateRunner.php
index ce64990141..4a5cf36808 100644
--- a/src/CronUpdateRunner.php
+++ b/src/CronUpdateRunner.php
@@ -6,7 +6,7 @@ namespace Drupal\automatic_updates;
 
 use Drupal\Core\Config\ConfigFactoryInterface;
 use Drupal\Core\CronInterface;
-use Drupal\Core\Utility\Error;
+use Drupal\package_manager\Error;
 use Drupal\package_manager\PathLocator;
 use Psr\Log\LoggerAwareInterface;
 use Psr\Log\LoggerAwareTrait;
@@ -92,13 +92,7 @@ class CronUpdateRunner implements CronInterface, LoggerAwareInterface {
       $pid = $this->commandExecutor->start($process);
     }
     catch (\Throwable $throwable) {
-      // @todo Just call Error::logException() in https://drupal.org/i/3377458.
-      if (method_exists(Error::class, 'logException')) {
-        Error::logException($this->logger, $throwable, 'Unable to start background update.');
-      }
-      else {
-        watchdog_exception('automatic_updates', $throwable, 'Unable to start background update.');
-      }
+      Error::logException($this->logger, $throwable, 'Unable to start background update.');
     }
 
     if ($process->isTerminated()) {
diff --git a/src/StatusCheckMailer.php b/src/StatusCheckMailer.php
index f940b5c0b4..b04cd02124 100644
--- a/src/StatusCheckMailer.php
+++ b/src/StatusCheckMailer.php
@@ -11,7 +11,7 @@ use Drupal\package_manager\ValidationResult;
 use Drupal\system\SystemManager;
 
 /**
- * Defines a service to send status check failure e-mails during cron.
+ * Defines a service to send status check failure emails during cron.
  *
  * @internal
  *   This is an internal part of Automatic Updates and may be changed or removed
diff --git a/tests/src/Build/CoreUpdateTest.php b/tests/src/Build/CoreUpdateTest.php
index 49060aa5a3..8ae706b9e7 100644
--- a/tests/src/Build/CoreUpdateTest.php
+++ b/tests/src/Build/CoreUpdateTest.php
@@ -14,6 +14,7 @@ use Drupal\package_manager\Event\PreApplyEvent;
 use Drupal\package_manager\Event\PreCreateEvent;
 use Drupal\package_manager\Event\PreRequireEvent;
 use Drupal\Tests\WebAssert;
+use Symfony\Component\Process\PhpExecutableFinder;
 use Symfony\Component\Process\Process;
 
 /**
@@ -153,10 +154,12 @@ class CoreUpdateTest extends UpdateTestBase {
     $this->createTestProject('RecommendedProject');
     $this->installModules(['automated_cron']);
 
-    // Reset the record of the last cron run, so that Automated Cron will be
-    // triggered at the end of this request.
+    // Reset the record of the last cron run.
     $this->visit('/automatic-updates-test-api/reset-cron');
     $this->getMink()->assertSession()->pageTextContains('cron reset');
+    // Make another request so that Automated Cron will be triggered at the end
+    // of the request.
+    $this->visit('/');
     $this->assertExpectedStageEventsFired(ConsoleUpdateStage::class, wait: 360);
     $this->assertCronUpdateSuccessful();
   }
@@ -442,9 +445,16 @@ class CoreUpdateTest extends UpdateTestBase {
     $this->createTestProject('RecommendedProject');
 
     $dir = $this->getWorkspaceDirectory() . '/project';
+
+    $command = [
+      (new PhpExecutableFinder())->find(),
+      $this->getWebRoot() . '/core/scripts/auto-update',
+    ];
+    // BEGIN: DELETE FROM CORE MERGE REQUEST
     // Use the `auto-update` command proxy that Composer puts into `vendor/bin`,
     // just to prove that it works.
     $command = [$dir . '/vendor/bin/auto-update'];
+    // END: DELETE FROM CORE MERGE REQUEST
     $process = new Process($command, $dir);
     // Give the update process as much time as it needs to run.
     $process->setTimeout(NULL)->mustRun();
diff --git a/tests/src/Functional/AutomaticUpdatesFunctionalTestBase.php b/tests/src/Functional/AutomaticUpdatesFunctionalTestBase.php
index e290bb1e67..7cc20dd5c6 100644
--- a/tests/src/Functional/AutomaticUpdatesFunctionalTestBase.php
+++ b/tests/src/Functional/AutomaticUpdatesFunctionalTestBase.php
@@ -46,6 +46,7 @@ abstract class AutomaticUpdatesFunctionalTestBase extends BrowserTestBase {
     $this->config('automatic_updates.settings')
       ->set('unattended.level', CronUpdateRunner::SECURITY)
       ->save();
+    $this->mockActiveCoreVersion('9.8.0');
   }
 
   /**
diff --git a/tests/src/Functional/StatusCheckFailureEmailTest.php b/tests/src/Functional/StatusCheckFailureEmailTest.php
index f1c6d0df2a..6e5b23fbb3 100644
--- a/tests/src/Functional/StatusCheckFailureEmailTest.php
+++ b/tests/src/Functional/StatusCheckFailureEmailTest.php
@@ -84,7 +84,7 @@ class StatusCheckFailureEmailTest extends AutomaticUpdatesFunctionalTestBase {
   }
 
   /**
-   * Tests that status check failures will trigger e-mails in some situations.
+   * Tests that status check failures will trigger emails in some situations.
    */
   public function testFailureNotifications(): void {
     // No messages should have been sent yet.
@@ -103,24 +103,24 @@ Your site has failed some readiness checks for automatic updates and may not be
 END;
     $this->assertMessagesSent('Automatic updates readiness checks failed', $expected_body);
 
-    // Running cron again should not trigger another e-mail (i.e., each
-    // recipient has only been e-mailed once) since the results are unchanged.
+    // Running cron again should not trigger another email (i.e., each
+    // recipient has only been emailed once) since the results are unchanged.
     $recipient_count = count($this->emailRecipients);
     $this->assertGreaterThan(0, $recipient_count);
     $sent_messages_count = $recipient_count;
     $this->runConsoleUpdateCommand();
     $this->assertSentMessagesCount($sent_messages_count);
 
-    // If a different error is flagged, they should be e-mailed again.
+    // If a different error is flagged, they should be emailed again.
     $error = $this->createValidationResult(SystemManager::REQUIREMENT_ERROR);
     TestSubscriber1::setTestResult([$error], StatusCheckEvent::class);
     $this->runConsoleUpdateCommand();
     $sent_messages_count += $recipient_count;
     $this->assertSentMessagesCount($sent_messages_count);
 
-    // If we flag the same error, but a new warning, they should not be e-mailed
+    // If we flag the same error, but a new warning, they should not be emailed
     // again because we ignore warnings by default, and they've already been
-    // e-mailed about this error.
+    // emailed about this error.
     $results = [
       $error,
       $this->createValidationResult(SystemManager::REQUIREMENT_WARNING),
@@ -129,14 +129,14 @@ END;
     $this->runConsoleUpdateCommand();
     $this->assertSentMessagesCount($sent_messages_count);
 
-    // If only a warning is flagged, they should not be e-mailed again because
+    // If only a warning is flagged, they should not be emailed again because
     // we ignore warnings by default.
     $warning = $this->createValidationResult(SystemManager::REQUIREMENT_WARNING);
     TestSubscriber1::setTestResult([$warning], StatusCheckEvent::class);
     $this->runConsoleUpdateCommand();
     $this->assertSentMessagesCount($sent_messages_count);
 
-    // If we stop ignoring warnings, they should be e-mailed again because we
+    // If we stop ignoring warnings, they should be emailed again because we
     // clear the stored results if the relevant configuration is changed.
     $config = $this->config('automatic_updates.settings');
     $config->set('status_check_mail', StatusCheckMailer::ALL)->save();
@@ -144,14 +144,14 @@ END;
     $sent_messages_count += $recipient_count;
     $this->assertSentMessagesCount($sent_messages_count);
 
-    // If we flag a different warning, they should be e-mailed again.
+    // If we flag a different warning, they should be emailed again.
     $warning = $this->createValidationResult(SystemManager::REQUIREMENT_WARNING);
     TestSubscriber1::setTestResult([$warning], StatusCheckEvent::class);
     $this->runConsoleUpdateCommand();
     $sent_messages_count += $recipient_count;
     $this->assertSentMessagesCount($sent_messages_count);
 
-    // If we flag multiple warnings, they should be e-mailed again because the
+    // If we flag multiple warnings, they should be emailed again because the
     // number of results has changed, even if the severity hasn't.
     $warnings = [
       $this->createValidationResult(SystemManager::REQUIREMENT_WARNING),
@@ -162,7 +162,7 @@ END;
     $sent_messages_count += $recipient_count;
     $this->assertSentMessagesCount($sent_messages_count);
 
-    // If we flag an error and a warning, they should be e-mailed again because
+    // If we flag an error and a warning, they should be emailed again because
     // the severity has changed, even if the number of results hasn't.
     $results = [
       $this->createValidationResult(SystemManager::REQUIREMENT_WARNING),
@@ -173,7 +173,7 @@ END;
     $sent_messages_count += $recipient_count;
     $this->assertSentMessagesCount($sent_messages_count);
 
-    // If we change the order of the results, they should not be e-mailed again
+    // If we change the order of the results, they should not be emailed again
     // because we are handling the possibility of the results being in a
     // different order.
     $results = array_reverse($results);
@@ -181,7 +181,7 @@ END;
     $this->runConsoleUpdateCommand();
     $this->assertSentMessagesCount($sent_messages_count);
 
-    // If we disable notifications entirely, they should not be e-mailed even
+    // If we disable notifications entirely, they should not be emailed even
     // if a different error is flagged.
     $config->set('status_check_mail', StatusCheckMailer::DISABLED)->save();
     $error = $this->createValidationResult(SystemManager::REQUIREMENT_ERROR);
@@ -190,7 +190,7 @@ END;
     $this->assertSentMessagesCount($sent_messages_count);
 
     // If we re-enable notifications and go back to ignoring warnings, they
-    // should not be e-mailed if a new warning is flagged.
+    // should not be emailed if a new warning is flagged.
     $config->set('status_check_mail', StatusCheckMailer::ERRORS_ONLY)->save();
     $warning = $this->createValidationResult(SystemManager::REQUIREMENT_WARNING);
     TestSubscriber1::setTestResult([$warning], StatusCheckEvent::class);
@@ -198,7 +198,7 @@ END;
     $this->assertSentMessagesCount($sent_messages_count);
 
     // If we disable unattended updates entirely and flag a new error, they
-    // should not be e-mailed.
+    // should not be emailed.
     $config->set('unattended.level', CronUpdateRunner::DISABLED)->save();
     $error = $this->createValidationResult(SystemManager::REQUIREMENT_ERROR);
     TestSubscriber1::setTestResult([$error], StatusCheckEvent::class);
diff --git a/tests/src/Traits/EmailNotificationsTestTrait.php b/tests/src/Traits/EmailNotificationsTestTrait.php
index 48a5eb0d43..6fc08edaa5 100644
--- a/tests/src/Traits/EmailNotificationsTestTrait.php
+++ b/tests/src/Traits/EmailNotificationsTestTrait.php
@@ -8,7 +8,7 @@ use Drupal\Core\Test\AssertMailTrait;
 use Drupal\Tests\user\Traits\UserCreationTrait;
 
 /**
- * Contains helper methods for testing e-mail sent by Automatic Updates.
+ * Contains helper methods for testing email sent by Automatic Updates.
  *
  * @internal
  */
@@ -30,7 +30,7 @@ trait EmailNotificationsTestTrait {
   protected $emailRecipients = [];
 
   /**
-   * Prepares the recipient list for e-mails related to Automatic Updates.
+   * Prepares the recipient list for emails related to Automatic Updates.
    */
   protected function setUpEmailRecipients(): void {
     // First, create a user whose preferred language is different from the
diff --git a/tests/src/Kernel/ConsoleUpdateStageTest.php b/tests/src/Kernel/ConsoleUpdateStageTest.php
index f017a3bc1e..6a5993f321 100644
--- a/tests/src/Kernel/ConsoleUpdateStageTest.php
+++ b/tests/src/Kernel/ConsoleUpdateStageTest.php
@@ -99,7 +99,7 @@ Congratulations!
 
 Drupal core was automatically updated from 9.8.0 to 9.8.1.
 
-This e-mail was sent by the Automatic Updates module. Unattended updates are not yet fully supported.
+This email was sent by the Automatic Updates module. Unattended updates are not yet fully supported.
 
 If you are using this feature in production, it is strongly recommended for you to visit your site and ensure that everything still looks good.
 END;
@@ -289,7 +289,7 @@ END;
       ->save();
     // Ensure that there is a security release to which we should update.
     $this->setReleaseMetadata([
-      'drupal' => __DIR__ . "/../../../package_manager/tests/fixtures/release-history/drupal.9.8.1-security.xml",
+      'drupal' => __DIR__ . '/../../../package_manager/tests/fixtures/release-history/drupal.9.8.1-security.xml',
     ]);
 
     // If an exception is thrown during destroy, it will not be caught by the
@@ -372,7 +372,7 @@ END;
       ->set('unattended.level', CronUpdateRunner::ALL)
       ->save();
     $this->setReleaseMetadata([
-      'drupal' => __DIR__ . "/../../../package_manager/tests/fixtures/release-history/drupal.9.8.1-security.xml",
+      'drupal' => __DIR__ . '/../../../package_manager/tests/fixtures/release-history/drupal.9.8.1-security.xml',
     ]);
     $this->setCoreVersion('9.8.0');
     $stage = $this->createStage();
@@ -412,7 +412,7 @@ END;
       ->set('unattended.level', CronUpdateRunner::ALL)
       ->save();
     $this->setReleaseMetadata([
-      'drupal' => __DIR__ . "/../../../package_manager/tests/fixtures/release-history/drupal.9.8.2.xml",
+      'drupal' => __DIR__ . '/../../../package_manager/tests/fixtures/release-history/drupal.9.8.2.xml',
     ]);
     $this->setCoreVersion('9.8.1');
     $stage = $this->createStage();
@@ -450,7 +450,7 @@ Congratulations!
 
 Drupal core was automatically updated from 9.8.0 to 9.8.1.
 
-This e-mail was sent by the Automatic Updates module. Unattended updates are not yet fully supported.
+This email was sent by the Automatic Updates module. Unattended updates are not yet fully supported.
 
 If you are using this feature in production, it is strongly recommended for you to visit your site and ensure that everything still looks good.
 END;
@@ -478,7 +478,7 @@ END;
   }
 
   /**
    * Tests the failure e-mail when an unattended non-security update fails.
    *
    * @param string $event_class
    *   The event class that should trigger the failure.
@@ -518,7 +518,7 @@ Drupal core failed to update automatically from 9.8.0 to 9.8.2. The following er
 
 No immediate action is needed, but it is recommended that you visit $url to perform the update, or at least check that everything still looks good.
 
-This e-mail was sent by the Automatic Updates module. Unattended updates are not yet fully supported.
+This email was sent by the Automatic Updates module. Unattended updates are not yet fully supported.
 
 If you are using this feature in production, it is strongly recommended for you to visit your site and ensure that everything still looks good.
 END;
@@ -526,7 +526,7 @@ END;
   }
 
   /**
    * Tests the failure e-mail when an unattended security update fails.
    *
    * @param string $event_class
    *   The event class that should trigger the failure.
@@ -560,7 +560,7 @@ Drupal core failed to update automatically from 9.8.0 to 9.8.1. The following er
 
 Your site is running an insecure version of Drupal and should be updated as soon as possible. Visit $url to perform the update.
 
-This e-mail was sent by the Automatic Updates module. Unattended updates are not yet fully supported.
+This email was sent by the Automatic Updates module. Unattended updates are not yet fully supported.
 
 If you are using this feature in production, it is strongly recommended for you to visit your site and ensure that everything still looks good.
 END;
@@ -568,7 +568,7 @@ END;
   }
 
   /**
    * Tests the failure e-mail when an unattended update fails to apply.
    */
   public function testApplyFailureEmail(): void {
     $this->getStageFixtureManipulator()->setCorePackageVersion('9.8.1');
@@ -581,7 +581,7 @@ Drupal core failed to update automatically from 9.8.0 to 9.8.1. The following er
 
 Automatic updates failed to apply, and the site is in an indeterminate state. Consider restoring the code and database from a backup. Caused by LogicException, with this message: {$error->getMessage()}
 
-This e-mail was sent by the Automatic Updates module. Unattended updates are not yet fully supported.
+This email was sent by the Automatic Updates module. Unattended updates are not yet fully supported.
 
 If you are using this feature in production, it is strongly recommended for you to visit your site and ensure that everything still looks good.
 END;
@@ -478,7 +478,7 @@ END;
 
   /**
-   * Tests the failure e-mail when an unattended non-security update fails.
+   * Tests the failure email when an unattended non-security update fails.
    *
    * @param string $event_class
@@ -526,7 +526,7 @@ END;
 
   /**
-   * Tests the failure e-mail when an unattended security update fails.
+   * Tests the failure email when an unattended security update fails.
    *
    * @param string $event_class
@@ -568,7 +568,7 @@ END;
 
   /**
-   * Tests the failure e-mail when an unattended update fails to apply.
+   * Tests the failure email when an unattended update fails to apply.
    */
   public function testApplyFailureEmail(): void {
-- 
GitLab